#
# spec file for package sddm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_rundir: %global _rundir /run}
%{!?_unitdir: %global _unitdir /usr/lib/systemd/system}

Name:           sddm
Version:        0.14.0
Release:        5.1
Summary:        QML-based display manager
License:        GPL-2.0+
Group:          System/GUI/KDE
Url:            https://github.com/sddm/sddm
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        %{name}.conf
Source2:        X11-displaymanagers-%{name}
# PATCH-FIX-UPSTREAM 0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch -- Revert to 0.13.0 config syntax
Patch0:         0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch
# PATCH-FIX-OPENSUSE proper_pam.diff -- Use openSUSE pam config
Patch1:         proper_pam.diff
# PATCH-FIX-OPENSUSE create_pid_file.patch -- openSUSE's generic display-manager service doesn't know what to do without a pid file. drop the patch as soon as that sick dinosaur is killed
Patch2:         create_pid_file.patch
# PATCH-FIX-OPENSUSE sddm-relaxed-auth.diff -- Insert XAUTHLOCALHOSTNAME into users enviroment, so the session handles hostname changes with a single X instance/run
# related patches: libxcb/bug-262309_xcb-xauthlocalhostname.diff, xauth/xauth-tolerant-hostname-changes.diff, kdebase4-workspace/kdm-relaxed-auth.diff
Patch3:         sddm-relaxed-auth.diff
# PATCH-FIX-OPENSUSE sysconfig-support.patch -- Support DISPLAYMANAGER_AUTOLOGIN entry from /etc/sysconfig/displaymanager, the value overwrites
# any entry in sddm.conf/[Autologin]/User. Patch also defaults to plasma5.desktop as default autologin session. This is controlled only by sddm.conf file.
Patch4:         sysconfig-support.patch
# PATCH-FIX-OPENSUSE sddm-service-handle-plymouth.patch -- sddm has some rudimentary support for plymouth handling, which only works with plymouth-quit.service
# (the servce is not enabled on openSUSE). For users of sddm.service, we need to issue plymouth quit command by hand in this case
Patch5:         sddm-service-handle-plymouth.patch
# PATCH-FIX-UPSTREAM 0001-Make-the-default-cursor-themed.patch -- Make the default cursor themed
Patch7:         0001-Make-the-default-cursor-themed.patch
# PATCH-FIX-OPENSUSE 0001-Systemd-service-unit-Use-tty7-by-default.patch -- Use tty7 by default in the systemd service unit
Patch8:         0001-Systemd-service-unit-Use-tty7-by-default.patch
# PATCH-FIX-UPSTREAM 0001-Also-theme-the-default-cursor-for-the-root-window.patch
Patch9:         0001-Also-theme-the-default-cursor-for-the-root-window.patch
# Bugfixes from upstream develop branch
Patch10:        0001-Fix-display-of-user-avatars.-684.patch
Patch11:        0002-Add-a-config-option-to-enable-high-DPI-scaling-701.patch
Patch12:        0003-elarun-Update-date-and-time.patch
Patch13:        0004-Support-Non-Latin-characters-in-theme-settings-708.patch
Patch14:        0005-Cleanup-dangling-pointer-in-SocketServer-725.patch
Patch15:        0001-Also-set-QT_IM_MODULE-in-non-testing-mode.patch
# PATCH-FIX-UPSTREAM 
Patch16:        0001-Parse-desktop-file-sections.patch
Patch17:        0002-Ignore-session-desktop-files-with-the-Hidden-propert.patch
# PATCH-FIX-OPENSUSE
Patch18:        0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
# PATCH-FIX-UPSTREAM
Patch19:        0001-Do-not-truncate-XAUTHORITY-file-on-login.patch
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules >= 1.4.0
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pam-devel
BuildRequires:  pkg-config
%if 0%{?sle_version} && !0%{?is_opensuse}
BuildRequires:  python-docutils
%else
BuildRequires:  python3-docutils
%endif
# Autodetect UID_MIN and UID_MAX from /etc/login.defs
BuildRequires:  shadow
BuildRequires:  pkgconfig(Qt5Core) >= 5.6.0
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(xcb-xkb)
Requires:       sddm-branding = %{version}
# Merged the -lang package back into the main package
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.

%package branding-openSUSE
Summary:        openSUSE branding for SDDM, a QML-based display manager
Group:          System/GUI/KDE
PreReq:         sddm
Requires:       sddm-theme-openSUSE
Supplements:    packageand(plasma5-workspace:branding-openSUSE)
Provides:       sddm-branding = %{version}
Conflicts:      otherproviders(sddm-branding)

%description branding-openSUSE
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.
This package provides the openSUSE branding for SDDM.

%package branding-upstream
Summary:        Upstream branding for SDDM, a QML-based display manager
Group:          System/GUI/KDE
Supplements:    packageand(plasma5-workspace:branding-upstream)
Provides:       sddm-branding = %{version}
Conflicts:      otherproviders(sddm-branding)

%description branding-upstream
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.
This package provides upstream branding for SDDM.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1

%build
%cmake \
      -DCMAKE_BUILD_TYPE=Release \
      -DMINIMUM_VT=7 \
      -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir}/%{name} \
      -DIMPORTS_INSTALL_DIR="%{_libdir}/qt5/qml" \
      -DSESSION_COMMAND="/etc/X11/xdm/Xsession" \
      -DBUILD_MAN_PAGES=ON \
      -DSTATE_DIR="/var/lib/sddm" \
      -DRUNTIME_DIR="/run/sddm" \
      -DPID_FILE="/run/sddm.pid"
  %make_jobs

%install
  %kf5_makeinstall -C build

  pushd %{buildroot}%{_sysconfdir}/dbus-1/system.d
  mv org.freedesktop.DisplayManager.conf sddm_org.freedesktop.DisplayManager.conf
  popd

  install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}.conf
  install -Dm 0644 %{SOURCE2} %{buildroot}%{_libexecdir}/X11/displaymanagers/%{name}
  install -d %{buildroot}%{_rundir}/sddm
  install -d %{buildroot}%{_localstatedir}/lib/sddm

  %fdupes -s %{buildroot}%{_datadir}/sddm

%pre
/usr/sbin/groupadd -r sddm 2> /dev/null || :
/usr/sbin/useradd -r -g sddm -s /bin/false -c "SDDM daemon" \
    -d /var/lib/sddm sddm 2> /dev/null || :

%post
if [ $1 -eq 2 -a -f /etc/sddm.conf ]; then
    sed -i -e 's/^Current=maui$/Current=/g' /etc/sddm.conf
fi

%post branding-openSUSE
if [ $1 -ge 1 -a -f /etc/sddm.conf ]; then
    # Upgrade from previous theme name
    sed -i -e 's/^Current=breeze$/Current=breeze-openSUSE/g' /etc/sddm.conf
    sed -i -e 's/^Current=maui$/Current=breeze-openSUSE/g' /etc/sddm.conf
fi
sed -i -e 's/^Current=$/Current=breeze-openSUSE/g' /etc/sddm.conf

%postun branding-openSUSE
if [ $1 -eq 0 -a -f /etc/sddm.conf ]; then
   sed -i -e 's/^Current=breeze-openSUSE$/Current=/g' /etc/sddm.conf
fi

%files
%defattr(-,root,root)
%doc LICENSE* README*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config %{_sysconfdir}/pam.d/sddm
%config %{_sysconfdir}/pam.d/sddm-autologin
%config %{_sysconfdir}/pam.d/sddm-greeter
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/sddm_org.freedesktop.DisplayManager.conf
%{_libexecdir}/sddm/
%dir %{_libexecdir}/X11/displaymanagers/
%{_libexecdir}/X11/displaymanagers/%{name}
%{_bindir}/sddm
%{_bindir}/sddm-greeter
%{_libdir}/qt5/qml/
%dir %{_datadir}/sddm/
%{_datadir}/sddm/faces/
%{_datadir}/sddm/flags/
%{_datadir}/sddm/scripts/
%{_datadir}/sddm/themes/
%{_datadir}/sddm/translations/
%{_mandir}/man*/sddm*.*
%ghost %attr(711,sddm,sddm) %dir %{_rundir}/sddm
%attr(750,sddm,sddm) %dir %{_localstatedir}/lib/sddm
%{_unitdir}/sddm.service

%files branding-openSUSE
%defattr(-,root,root)
%doc LICENSE* README*

%files branding-upstream
%defattr(-,root,root)
%doc LICENSE* README*

%changelog
* Mon Jul 10 2017 fabian@ritter-vogt.de
- Replace patch with version merged upstream, to avoid potentially
  killing the X server:
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
* Fri Jul  7 2017 fabian@ritter-vogt.de
- Add patch to keep old entries in XAUTHORITY file (boo#1043221):
  * 0001-Do-not-truncate-XAUTHORITY-file-on-login.patch
* Fri May 19 2017 fabian@ritter-vogt.de
- Also set the default last session in sysconfig-support.patch
  (replaces boo949903.patch)
- Adjust 0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
  to also handle symlinks for the last session
* Thu May 18 2017 fabian@ritter-vogt.de
- Replace patch with newer version:
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
* Mon May 15 2017 fvogt@suse.com
- Add upstream patches:
  * 0001-Parse-desktop-file-sections.patch
  * 0002-Ignore-session-desktop-files-with-the-Hidden-propert.patch
- Add downstream patch:
  * 0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
- Fix typo in sysconfig-support.patch (DYSPLAY -> DISPLAY)
- Use default.desktop as default autologin session file
* Mon May  8 2017 fabian@ritter-vogt.de
- BuildRequire python-docutils instead of python3-docutils on SLE
* Fri May  5 2017 fabian@ritter-vogt.de
- Add patch to fix the default X cursor appearing sometimes:
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
* Tue Apr 25 2017 fabian@ritter-vogt.de
- BuildRequire python3-docutils directly
* Sat Apr  1 2017 fabian@ritter-vogt.de
- Use default tty (tty7) in systemd unit as specified in sddm.conf:
  * 0001-Systemd-service-unit-Use-tty7-by-default.patch
- Add patch from upstream to allow setting QT_IM_MODULE in sddm.conf:
  * 0001-Also-set-QT_IM_MODULE-in-non-testing-mode.patch
* Fri Mar 31 2017 fabian@ritter-vogt.de
- Revert calling plymouth quit with --retain-splash. It is possible
  that this prevents logging in on tty1.
* Fri Mar 17 2017 jengelh@inai.de
- Ensure neutrality of descriptions.
* Wed Mar  8 2017 wbauer@tmo.at
- Call "plymouth quit --retain-splash" instead of "plymouth_quit"
  in the displaymanager script to hide the text mode login prompt
  during boot (the dedicated sddm.service does the same).
- Also, don't call xdm_reload_files, that just re-generates the xdm
  config files according to the sysconfig values and only makes
  sense for xdm.
* Sat Dec 17 2016 fabian@ritter-vogt.de
- Fix typos in description
* Fri Nov 25 2016 fabian@ritter-vogt.de
- Fix %%post and %%postun of branding subpackages
* Mon Nov 21 2016 fabian@ritter-vogt.de
- Add various bugfixes from develop branch:
  * 0001-Fix-display-of-user-avatars.-684.patch
  * 0002-Add-a-config-option-to-enable-high-DPI-scaling-701.patch
  * 0003-elarun-Update-date-and-time.patch
  * 0004-Support-Non-Latin-characters-in-theme-settings-708.patch
  * 0005-Cleanup-dangling-pointer-in-SocketServer-725.patch
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Sync with KDE:Frameworks5:LTS, sort sddm.changes
- Remove 0001-Fall-back-to-regular-login-when-autologin-fails.patch
* Sat Sep 24 2016 fabian@ritter-vogt.de
- Add 0001-Fall-back-to-regular-login-when-autologin-fails.patch
  to fix crash when autologin session not found (boo#1000917)
* Thu Sep 22 2016 fabian@ritter-vogt.de
- Add 0001-Make-the-default-cursor-themed.patch to fix the default
  cursor appearance
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Provide sddm-lang
* Thu Sep 15 2016 alarrosa@suse.com
- Use the new theme name, breeze-openSUSE, in sddm-branding-openSUSE
- Require the new sddm-theme-openSUSE package
* Mon Aug 29 2016 fabian@ritter-vogt.de
- Update to 0.14.0:
  - http://hawaiios.org/news/2016/08/28/sddm-0.14.0
    + New sddm.conf option EnableAvatars (useful for slow filesystems)
    + New sddm.conf option UserAuthFile on the XDisplay section
    to change the default Xauthority file name and path.
    + New sddm.conf option SessionLogFile on XDisplay and WaylandDisplay
    sections to change the default user session log location.
    + ComboBox now exposes the arrow background color as
    "arrowColor" property.
    + New "style" theme configuration for QtQuick Controls 2.0.
    + Require Qt 5.6 or better.
    + Enable HiDPI support.
    + Refresh sessions list.
    + Always fallback to an embedded theme if no suitable theme is found.
  - Actually change Qt platform theme.
  - Switch to Wayland session vt only when authentication
    succeeds.
  - Close PAM session.
  - Delete PAM credentials after closing the session.
  * More theme-neutral default user and root avatars
  * REMOVED the "circles" theme. Remember to change it if you had it set!
  * REMOVED the "maui" theme as a standalone theme as it is now
    embedded in the greeter. Remember to change the theme to empty
    if you had it set to "maui".
  * Update Estonian translation.
  * Add Catalan translation from Robert Antoni Buj Gelonch.
  * Add Dutch translation from Eric Hameleers.
  * Add Slovak translation from Martin Minka.
  * Add Swedish translation from Kristoffer Grundström.
  * Add Ukrainian translation from Cherevan Andriy.
  * Add Indian flag from Sanjeev Premi.
- Refresh patches:
  - sddm-relaxed-auth.diff
  - sddm-service-handle-plymouth.patch
  - sysconfig-support.patch
- Remove upstream patches:
  - 0001-Add-a-config-option-to-enable-avatars.patch
  - 0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch
  - root.face.icon.png
  - default.face.icon.png
- Remove upstreamed patches:
  - add-count-property-to-UserModel.patch
  - add-threshold-to-disable-avatars.patch
  - specify-default-config-entries.patch
- Revert upstream config section name change (gh#sddm/sddm#680):
  - 0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch
- Use "Current=" instead of "Current=maui"
* Wed Jun  8 2016 fbui@suse.com
- Fix build requirements on systemd (bsc#983167)
  Use pkgconfig() so we don't need to rely on package names. For the
  record, systemd.pc is now part of systemd main package.
* Fri Nov 20 2015 alarrosa@suse.com
- Renamed config option and property from UsersThresholdToDisableAvatars
  to DisableAvatarsThreshold as proposed by upstream before accepting
  the patches.
* Wed Nov 11 2015 alarrosa@suse.com
- Add patch add-count-property-to-UserModel.patch: Adds a property so
  sddm themes can access the number of users in the system
- Add patch specify-default-config-entries.patch: Stores which config
  values have been read from the config file or are just default values.
- Add patch add-threshold-to-disable-avatars.patch: Adds a config option
  and property named UsersThresholdToDisableAvatars, if the number of
  users in the system is greater than the threshold, use a default avatar
  for all users and disable avatar loading.
- These patches together with patches in plasma5-workspace fix bnc#953778
* Fri Nov  6 2015 alarrosa@suse.com
- Update to 0.13.0:
  * Greeter inherits path environment variables from parent so that
    themes installed in non-standard paths will work.
  * Add ENABLE_PAM option to toggle PAM support at build time.
  * Allow overriding textColor in ComboBox.
  * Don't cast QByteArray to (char *).
  * Disable greeters from loading KDE's debug hander
    (fix CVE-2015-0856).
  * Fix multi-screen support for some setups.
  * Added Serbian translation.
  * Added Traditional Chinese translation.
  * Improved German translation.
  * Remove failsafe session entry.
  * Close the pipe fd passed to X server.
  * A few micro-optimizations.
- Removed patches already in this version:
    0001-always-create-window-for-each-screen.patch
    0002-screen-model-for-each-window.patch
    0001-Don-t-cast-QByteArray-to-char.patch
    0002-Disable-greeters-from-loading-KDE-s-debug-hander.patch
- Updated patches to apply cleanly:
    boo949903.patch
    sddm-relaxed-auth.diff
    sysconfig-support.patch
- Added patches from upstream to add a config option that can be
  used to disable the loading of user avatars (EnableAvatars):
    0001-Add-a-config-option-to-enable-avatars.patch
    0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch
* Sat Oct 24 2015 tchvatal@suse.com
- Add upstream patches to fix multihead in some cases
  (also fixes boo#950293):
  * 0001-always-create-window-for-each-screen.patch
  * 0002-screen-model-for-each-window.patch
* Sun Oct 18 2015 hrvoje.senjan@gmail.com
- openSUSE branding now needs to require plasma5-workspace-branding
* Thu Oct 15 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Don-t-cast-QByteArray-to-char.patch
  (https://github.com/sddm/sddm/issues/489)
  and 0002-Disable-greeters-from-loading-KDE-s-debug-hander.patch
  (boo#950491, CVE-2015-0856)
* Sun Oct 11 2015 hrvoje.senjan@gmail.com
- Added boo949903.patch: Let sddm also default to plasma5 for last
  used session (boo#949903)
* Thu Sep 24 2015 hrvoje.senjan@gmail.com
- Added shadow BuildRequires, it's needed to check UID_MIN & UID_MAX
  from /etc/login.defs
* Sat Sep 12 2015 wbauer@tmo.at
- Change the theme to "maui" in the shipped sddm.conf,
  sddm-branding-openSUSE sets it to "breeze" on installation.
- Remove the superfluous requirement for "breeze". This is not
  needed even with the "breeze" theme, as it is actually part of
  plasma5-workspace which is required by sddm-branding-openSUSE
  anyway.
- sddm-branding-openSUSE should PreReq sddm, otherwise the config
  might not exist.
- Make the regexps for sed stricter to really only modify the theme
  setting when installing/uninstalling sddm-branding-openSUSE.
  Otherwise it would e.g. also replace CursorTheme=breeze_cursors
  with CursorTheme=maui_cursors...
  Also only modify the config on new installation, not during
  updates.
* Sun Sep  6 2015 hrvoje.senjan@gmail.com
- Update to 0.12.0:
  * SDDM now depends on Qt >= 5.3
  * Display setup script is now killed if it hasn't finished
    within 30 seconds.
  * The Maldives non-free background has been replaced by a
    CC-BY-SA alternative
  * Wayland sessions support
  * New sddm.conf option XephyrPath
    (defaults to /usr/bin/Xephyr)
  * new sddm.conf option ServerArguments
    (defaults to -nolisten tcp)
  * new sddm.config option DisplayStopCommand (executes Xstop)
  * Assorted improvements to the default theme
  * Honor TryExec in Xsession desktop files
  * Fix session startup on zsh
  * Allow setting a custom DBUS_CONFIG_FILENAME at compile time
  * Allow SYSTEMD_SYSTEM_UNIT_DIR to be overridden at compile time
  * Allow QT_IMPORTS_DIR to be overridden at compile time
  * No longer hardcode min/max UIDs, allow setting
    UID_MIN and UID_MAX at compile time
  * Assorted FreeBSD fixes
  * Fix build warnings with Qt 5.5.
  * Enable QT_NO_CAST_FROM_ASCII
  * Added Arabic
  * Added Hungarian
  * Various i18n updates and improvements
  * Full right-to-left languages support.
- Drop sddm-wait-for-display-script.patch, merged upstream
* Wed Aug 26 2015 herbert@graeber-clan.de
- Added patch from upstream sddm-wait-for-display-script.patch:
  avoid a black screen (boo#942815)
* Mon Jun  1 2015 dimstar@opensuse.org
- Do not split out a -lang package: the translations are not in
  standard locations and having the -lang package confuses
  bundle-lang-kde, which can't move the files to the bundle, thus
  resulting in conflicting packages.
* Mon May 25 2015 hrvoje.senjan@gmail.com
- Add sddm-service-handle-plymouth.patch -- sddm has some rudimentary
  support for plymouth handling, which only works with
  plymouth-quit.service (the servce is not enabled on openSUSE).
  For users of sddm.service, we need to issue plymouth quit command
  by hand in this case
* Mon May  4 2015 hrvoje.senjan@gmail.com
- Add sysconfig-support.patch: Support DISPLAYMANAGER_AUTOLOGIN
  entry from /etc/sysconfig/displaymanager, the value overwrites
  any entry in sddm.conf/[Autologin]/User. Patch also defaults
  to plasma5.desktop as default autologin and last selected
  sessions. This is controlled only by sddm.conf file.
- Mark sddm.conf as %%config(noreplace)
* Wed Apr 29 2015 hrvoje.senjan@gmail.com
- Added sddm-relaxed-auth.diff: Insert XAUTHLOCALHOSTNAME into
  users enviroment, so the session handles hostname changes with
  a single X instance/run
- Use breeze_cursors in openSUSE branding
* Mon Mar 16 2015 hrvoje.senjan@gmail.com
- Drop conflict with lightdm, and move DBus configuration file,
  now that sddm is whitelisted
- Drop xdm (Build)Requires
- Install sddm-pam* directly, instead of messing with symlinking
- Add create_pid_file.patch: openSUSE's generic display-manager
  service doesn't know what to do without a pid file. drop the patch
  as soon as that sick dinosaur is killed
- Drop ommit_systemd_service.patch
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Add conflict with lightdm due to same DBus configuration file
* Mon Dec  8 2014 hrvoje.senjan@gmail.com
- Update to 0.11.0
  * Reload the configuration every time we start a new session
  * Fix stderr redirection in the helper. Solving a memory leak
  * Set system locale in the greeter
  * Bail on chdir failure
  * Use QUuid for unique ID generation
  * Update lithuanian translations
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Create openSUSE and upstream branding packages, now only openSUSE
  branding depends on plasma5-workspace
* Fri Oct 17 2014 hrvoje.senjan@gmail.com
- Update to 0.10.0:
  * BACKWARDS INCOMPATIBLE: Drop support for Qt 4.
  * BACKWARDS INCOMPATIBLE: SDDM now prioritizes loading sessions
    with a .desktop prefix
  * SECURITY: Never try to login as the sddm user (CVE-2014-7271)
  * SECURITY: Fix race condition in XAUTHORITY file generation
    (CVE-2014-7272)
  * SECURITY: XAUTHORITY file is no longer owned by root
  * New translation: Kazakh
  * Fixed password field initial focus state
  * When the default theme is not available, sddm now loads the
    first theme in alphabetical order
  * Fixed PAM environment variables being overridden
  * Fixed autologin with the passwd backend
  * Greeter themes can now specify their own icon and
    cursor themes.
  * Various bugfixes with SessionCommand/XSession support
  * Various bugfixes with test mode.
  * Various cleanups
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 0.9.9~git20141009:
  * resolved CVE-2014-7272 and bnc#897788
  * Dropped support for Qt4
  * Flush any buffered data to the log file, this writes
    immediately all the log messages.
  * Don't override pam environment variables.
  * Set default icon theme from greeter theme configuration.
  * Set cursor theme according to greeter theme configuration.
- Drop 0001-Never-try-to-login-as-the-user-SDDM.patch,
  0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch
  and 0001-Don-t-override-pam-environment-variables.patch: merged
  upstream
* Mon Oct  6 2014 hrvoje.senjan@gmail.com
- Added 0001-Never-try-to-login-as-the-user-SDDM.patch and
  0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch to
  resolve bnc#897788 and CVE-2014-7272
- Leave 0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch
  disabled for the moment, as it completely breaks users login
* Sun Sep 21 2014 hrvoje.senjan@gmail.com
- Make it build for 13.1: define /rundir if undefined
- 0001-Don-t-override-pam-environment-variables.patch: fixes
  https://github.com/sddm/sddm/issues/256
* Thu Aug 21 2014 hrvoje.senjan@gmail.com
- Update to 0.9.0
  * Several systemd, logind and journald improvements. Note that
    systemd is not required to run SDDM.
  * The SDDM greeter now runs as its own user and group, instead
    of root.
  * Support for setting the keyboard layout from the greeter.
  * An "AutoUser" config key to configure automatic login.
  * A "NumLock" config key to configure NumLock state at boot.
  * Overhauled configuration file handling.
  * SDDM runs with the default configuration without /etc/sddm.conf
  * Initial (albeit not fully functional) Plymouth support.
  * Translations in 11 languages.
  * Several licensing and packaging improvements.
  * Better documentation, including man pages for sddm(1),
    sddm-greeter(1), sddm.conf(5) and sddm-state.conf(5).
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Update to latest snapshot
- Added pkgconfig(xcb-xkb) BuildRequires
- Dropped libupower-glib-devel BuildRequire
- Utilize systemd macros for sddm service
- Small spec cleanup
- Use sed instead of two patches
* Sun Mar 17 2013 hrvoje.senjan@gmail.com
- Initial packaging of sddm, Lightweight QML-based display manager
